@@ -15,7 +15,7 @@ import lombok.ToString;
  */
 @NoArgsConstructor
 @ToString(callSuper=true)
-public class WorkspaceVREFolder extends WorkspaceFolder implements org.gcube.common.storagehubwrapper.shared.tohl.WorkspaceVREFolder{
+public class WorkspaceVREFolder extends WorkspaceSharedFolder implements org.gcube.common.storagehubwrapper.shared.tohl.WorkspaceVREFolder{
 	/**
 	 *
 	 */
